# Generated by Django 5.1.5 on 2025-02-05 01:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('authit', '0003_alter_user_modified'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='last_activity',
            field=models.DateTimeField(db_index=True, default=None, null=True),
        ),
    ]
