# Generated by Django 5.1.6 on 2025-02-09 19:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('authit', '0005_remove_group_permissions_groupmember'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='uuid',
            field=models.CharField(db_index=True, default=None, max_length=200, null=True),
        ),
    ]
